@@ -51,6 +51,8 @@
 # 19-May-2019 jdw add method __getStructConfInfo()
 # 21-May-2019 jdw handle odd ordering of records in struct_ref_seq_dif.
 # 25-Nov-2019 jdw add method normalizeCitationJournalAbbrev() and dependencies
+# 11-Mar-2022 bv Fix _rcsb_entry_info.deposited_model_count not being populated for certain NMR entries
+# 28-Mar-2022 bv Move 'getRepresentativeModels' method to DictMethodCommonUtils
 #
 ##
 """
@@ -875,10 +877,15 @@ class DictMethodEntryHelper(object):
             # INSTANCE FEATURES
             #
             ##
-            repModelL = ["1"]
-            if self.__commonU.hasMethodNMR(methodL):
-                repModelL = self.__getRepresentativeModels(dataContainer)
-            logger.debug("Representative model list %r", repModelL)
+            repModelL = []
+            mIdL = self.__commonU.getModelIdList(dataContainer)
+            if mIdL:
+                repModelL = ["1"] if "1" in mIdL else [mIdL[0]]
+                if self.__commonU.hasMethodNMR(methodL):
+                    repModelL = self.__commonU.getRepresentativeModels(dataContainer)
+                logger.debug("Representative model list %r %r", repModelL, entryId)
+            else:
+                logger.debug("No models available for %s", dataContainer.getName())
             #
             instanceTypeCountD = self.__commonU.getInstanceTypeCounts(dataContainer)
             cObj.setValue(instanceTypeCountD["polymer"], "deposited_polymer_entity_instance_count", 0)
@@ -1077,54 +1084,6 @@ class DictMethodEntryHelper(object):
             logger.exception("%s %s %s failing with %s", dataContainer.getName(), catName, atName, str(e))
         return False
 
-    def __getRepresentativeModels(self, dataContainer):
-        """Return the list of representative models
-
-        Example:
-            #
-            _pdbx_nmr_ensemble.entry_id                                      5TM0
-            _pdbx_nmr_ensemble.conformers_calculated_total_number            15
-            _pdbx_nmr_ensemble.conformers_submitted_total_number             15
-            _pdbx_nmr_ensemble.conformer_selection_criteria                  'all calculated structures submitted'
-            _pdbx_nmr_ensemble.representative_conformer                      ?
-            _pdbx_nmr_ensemble.average_constraints_per_residue               ?
-            _pdbx_nmr_ensemble.average_constraint_violations_per_residue     ?
-            _pdbx_nmr_ensemble.maximum_distance_constraint_violation         ?
-            _pdbx_nmr_ensemble.average_distance_constraint_violation         ?
-            _pdbx_nmr_ensemble.maximum_upper_distance_constraint_violation   ?
-            _pdbx_nmr_ensemble.maximum_lower_distance_constraint_violation   ?
-            _pdbx_nmr_ensemble.distance_constraint_violation_method          ?
-            _pdbx_nmr_ensemble.maximum_torsion_angle_constraint_violation    ?
-            _pdbx_nmr_ensemble.average_torsion_angle_constraint_violation    ?
-            _pdbx_nmr_ensemble.torsion_angle_constraint_violation_method     ?
-            #
-            _pdbx_nmr_representative.entry_id             5TM0
-            _pdbx_nmr_representative.conformer_id         1
-            _pdbx_nmr_representative.selection_criteria   'fewest violations'
-        """
-        repModelL = []
-        if dataContainer.exists("pdbx_nmr_representative"):
-            tObj = dataContainer.getObj("pdbx_nmr_representative")
-            if tObj.hasAttribute("conformer_id"):
-                for ii in range(tObj.getRowCount()):
-                    nn = tObj.getValue("conformer_id", ii)
-                    if nn is not None and nn.isdigit():
-                        repModelL.append(nn)
-
-        if dataContainer.exists("pdbx_nmr_ensemble"):
-            tObj = dataContainer.getObj("pdbx_nmr_ensemble")
-            if tObj.hasAttribute("representative_conformer"):
-                nn = tObj.getValue("representative_conformer", 0)
-                if nn is not None and nn and nn.isdigit():
-                    repModelL.append(nn)
-        #
-        repModelL = list(set(repModelL))
-        if not repModelL:
-            logger.debug("Missing representative model data for %s using 1", dataContainer.getName())
-            repModelL = ["1"]
-
-        return repModelL
-
     def __filterExperimentalResolution(self, dataContainer):
         """Collect resolution estimates from method specific sources."""
         rL = []
